pub struct PagedIntrospector { /* private fields */ }Expand description
An introspector implementation for paged documents.
Implementations
Sourceimpl PagedIntrospector
impl PagedIntrospector
Sourcepub fn new(pages: &[Page]) -> PagedIntrospector
pub fn new(pages: &[Page]) -> PagedIntrospector
Creates an introspector for a paged document.
Sourcepub fn position(&self, location: Location) -> Option<PagedPosition>
pub fn position(&self, location: Location) -> Option<PagedPosition>
Resolves the position of the location in the pages.
Sourcepub fn elements(&self) -> &ElementIntrospector<PagedPosition>
pub fn elements(&self) -> &ElementIntrospector<PagedPosition>
The underlying element introspector.
Sourcepub fn frame_link_targets(&self) -> &FxHashSet<Location>
pub fn frame_link_targets(&self) -> &FxHashSet<Location>
Returns the locations that the paged document links to via
FrameItem::Link.